'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ButtonGroup = exports.ButtonGroupColors = exports.ButtonGroupSizes = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Button group size enumerable.
 *
 * @type {{TINY: string, SMALL: string, LARGE: string}}
 */
var ButtonGroupSizes = exports.ButtonGroupSizes = {
  TINY: 'tiny',
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Button group color enumerable.
 *
 * @type {{PRIMARY: string, SECONDARY: string, SUCCESS: string, ALERT: string, WARNING: string}}
 */
var ButtonGroupColors = exports.ButtonGroupColors = {
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  ALERT: 'alert',
  WARNING: 'warning'
};

/**
 * Button group component.
 * http://foundation.zurb.com/sites/docs/button-group.html
 *
 * @param {Object} props
 * @returns {Object}
 */
var ButtonGroup = exports.ButtonGroup = function ButtonGroup(props) {
  // TODO: Consider validating both size and color values.
  _checkTypes2.default.assert.maybe.string(props.size, 'Property "size" must be a string.');
  _checkTypes2.default.assert.maybe.string(props.color, 'Property "color" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Property "isExpanded" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isStacked, 'Property "isStacked" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.stackForSmall, 'Property "stackedForSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.stackForMedium, 'Property "stackedForMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.stackForLarge, 'Property "stackedForLarge" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'button-group', props.size, props.color, {
    'expanded': props.isExpanded,
    'stacked': props.isStacked,
    'stacked-for-small': props.stackedForSmall,
    'stacked-for-medium': props.stackedForMedium,
    'stacked-for-large': props.stackedForLarge
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, (0, _utils.removeProps)(props, ['color']), { className: className }));
};

exports.default = ButtonGroup;