'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Link = exports.Button = exports.ButtonColors = exports.ButtonSizes = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Button size enumerable.
 *
 * @type {{TINY: string, SMALL: string, LARGE: string}}
 */
var ButtonSizes = exports.ButtonSizes = {
  TINY: 'tiny',
  SMALL: 'small',
  LARGE: 'large'
};

/**
 * Button color enumerable.
 *
 * @type {{PRIMARY: string, SECONDARY: string, SUCCESS: string, ALERT: string, WARNING: string}}
 */
var ButtonColors = exports.ButtonColors = {
  PRIMARY: 'primary',
  SECONDARY: 'secondary',
  SUCCESS: 'success',
  ALERT: 'alert',
  WARNING: 'warning'
};

/**
 * Button component.
 * http://foundation.zurb.com/sites/docs/button.html
 *
 * @param {Object} props
 * @returns {Object}
 */
var Button = exports.Button = function Button(props) {
  return _react2.default.createElement('button', _extends({}, (0, _utils.removeProps)(props, ['color']), { className: createButtonClassName(props) }));
};

/**
 * Link button component.
 * http://foundation.zurb.com/sites/docs/button.html#basics
 *
 * @param {Object} props
 * @returns {Object}
 */
var Link = exports.Link = function Link(props) {
  return _react2.default.createElement('a', _extends({}, (0, _utils.removeProps)(props, ['color']), { className: createButtonClassName(props) }));
};

/**
 * Creates the button class name from the given properties.
 * This method allows us to share code between the `Button` and `Link` components.
 *
 * @param {Object} props
 * @returns {string}
 */
function createButtonClassName(props) {
  // TODO: Consider validating both size and color values.
  _checkTypes2.default.assert.maybe.string(props.size, 'Property "size" must be a string.');
  _checkTypes2.default.assert.maybe.string(props.color, 'Property "color" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.isHollow, 'Property "isHollow" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Property "isExpanded" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isDisabled, 'Property "isDisabled" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isDropdown, 'Property "isDropdown" must be a boolean.');

  return (0, _utils.createClassName)(props.className || 'button', props.size, props.color, {
    'hollow': props.isHollow,
    'expanded': props.isExpanded,
    'disabled': props.isDisabled,
    'dropdown': props.isDropdown,
    'arrow-only': props.isArrowOnly
  }, (0, _utils.generalClassNames)(props));
}

exports.default = Button;