'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Column = exports.Row = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _lodash = require('lodash.has');

var _lodash2 = _interopRequireDefault(_lodash);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Row component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var Row = exports.Row = function Row(props) {
  _checkTypes2.default.assert.maybe.string(props.horizontalAlignment, 'Property "horizontalAlignment" must be a string.');
  _checkTypes2.default.assert.maybe.string(props.verticalAlignment, 'Property "verticalAlignment" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.unstackOnSmall, 'Property "unstackOnSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.unstackOnMedium, 'Property "unstackOnMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.unstackOnLarge, 'Property "unstackOnLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isColumn, 'Property "isColumn" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Property "isExpanded" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'row', {
    'align-right': props.horizontalAlignment === _utils.HorizontalAlignments.RIGHT,
    'align-center': props.horizontalAlignment === _utils.HorizontalAlignments.CENTER,
    'align-justify': props.horizontalAlignment === _utils.HorizontalAlignments.JUSTIFY,
    'align-spaced': props.horizontalAlignment === _utils.HorizontalAlignments.SPACED,
    'align-top': props.verticalAlignment === _utils.VerticalAlignments.TOP,
    'align-middle': props.verticalAlignment === _utils.VerticalAlignments.MIDDLE,
    'align-bottom': props.verticalAlignment === _utils.VerticalAlignments.BOTTOM,
    'align-stretch': props.verticalAlignment === _utils.VerticalAlignments.STRETCH,
    'small-unstack': props.unstackOnSmall,
    'medium-unstack': props.unstackOnMedium,
    'large-unstack': props.unstackOnLarge,
    'column': props.isColumn,
    'expanded': props.isExpanded
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, props, { className: className }));
};

/**
 * Column component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var Column = exports.Column = function Column(props) {
  _checkTypes2.default.assert.maybe.number(props.small, 'Property "small" must be a number.');
  _checkTypes2.default.assert.maybe.number(props.medium, 'Property "medium" must be a number.');
  _checkTypes2.default.assert.maybe.number(props.large, 'Property "large" must be a number.');
  _checkTypes2.default.assert.maybe.object(props.offset, 'Property "offset" must be an object.');
  _checkTypes2.default.assert.maybe.object(props.push, 'Property "push" must be an object.');
  _checkTypes2.default.assert.maybe.object(props.pull, 'Property "pull" must be an object.');
  _checkTypes2.default.assert.maybe.object(props.up, 'Property "up" must be an object.');
  _checkTypes2.default.assert.maybe.object(props.order, 'Property "order" must be an object.');
  _checkTypes2.default.assert.maybe.boolean(props.collapseOnSmall, 'Property "collapseOnSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.collapseOnMedium, 'Property "collapseOnMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.collapseOnLarge, 'Property "collapseOnLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncollapseOnSmall, 'Property "uncollapseOnSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncollapseOnMedium, 'Property "uncollapseOnMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncollapseOnLarge, 'Property "uncollapseOnLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.centerOnSmall, 'Property "centerOnSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.centerOnMedium, 'Property "centerOnMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.centerOnLarge, 'Property "centerOnLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncenterOnSmall, 'Property "uncenterOnSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncenterOnMedium, 'Property "uncenterOnMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.uncenterOnLarge, 'Property "uncenterOnLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.expandOnSmall, 'Property "expandOnSmall" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.expandOnMedium, 'Property "expandOnMedium" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.expandOnLarge, 'Property "expandOnLarge" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.shrink, 'Property "shrink" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isLast, 'Property "isLast" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'columns', props.small ? 'small-' + props.small : null, props.medium ? 'medium-' + props.medium : null, props.large ? 'large-' + props.large : null, (0, _lodash2.default)(props, 'offset.small') ? 'small-offset-' + props.offset.small : null, (0, _lodash2.default)(props, 'offset.medium') ? 'medium-offset-' + props.offset.medium : null, (0, _lodash2.default)(props, 'offset.large') ? 'large-offset-' + props.offset.large : null, (0, _lodash2.default)(props, 'push.small') ? 'small-push-' + props.push.small : null, (0, _lodash2.default)(props, 'push.medium') ? 'medium-push-' + props.push.medium : null, (0, _lodash2.default)(props, 'push.large') ? 'large-push-' + props.push.large : null, (0, _lodash2.default)(props, 'pull.small') ? 'small-pull-' + props.pull.small : null, (0, _lodash2.default)(props, 'pull.medium') ? 'medium-pull-' + props.pull.medium : null, (0, _lodash2.default)(props, 'pull.large') ? 'large-pull-' + props.pull.large : null, (0, _lodash2.default)(props, 'up.small') ? 'small-up-' + props.up.small : null, (0, _lodash2.default)(props, 'up.medium') ? 'medium-up-' + props.up.medium : null, (0, _lodash2.default)(props, 'up.large') ? 'large-up-' + props.up.large : null, (0, _lodash2.default)(props, 'order.small') ? 'small-order-' + props.order.small : null, (0, _lodash2.default)(props, 'order.medium') ? 'medium-order-' + props.order.medium : null, (0, _lodash2.default)(props, 'order.large') ? 'large-order-' + props.order.large : null, {
    'collapse-small': props.collapseOnSmall,
    'collapse-medium': props.collapseOnMedium,
    'collapse-large': props.collapseOnLarge,
    'uncollapse-small': props.uncollapseOnSmall,
    'uncollapse-medium': props.uncollapseOnMedium,
    'uncollapse-large': props.uncollapseOnLarge,
    'small-centered': props.centerOnSmall,
    'medium-centered': props.centerOnMedium,
    'large-centered': props.centerOnLarge,
    'small-uncentered': props.uncenterOnSmall,
    'medium-uncentered': props.uncenterOnMedium,
    'large-uncentered': props.uncenterOnLarge,
    'small-expand': props.expandOnSmall,
    'medium-expand': props.expandOnMedium,
    'large-expand': props.expandOnLarge,
    'shrink': props.shrink,
    'end': props.isLast
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, (0, _utils.removeProps)(props, ['offset']), { className: className }));
};