'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MediaObjectSection = exports.MediaObject = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Media object component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var MediaObject = exports.MediaObject = function MediaObject(props) {
  _checkTypes2.default.assert.maybe.boolean(props.stackForSmall, 'Property "stackForSmall" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'media-object', {
    'stack-for-small': props.stackForSmall
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, props, { className: className }));
};

/**
 * Media object section component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var MediaObjectSection = exports.MediaObjectSection = function MediaObjectSection(props) {
  _checkTypes2.default.assert.maybe.string(props.alignment, 'Property "alignment" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.isMain, 'Property "isMain" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isMiddle, 'Property "isMiddle" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isBottom, 'Property "isBottom" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'media-object-section', {
    'align-self-center': props.alignment === _utils.HorizontalAlignments.CENTER,
    'align-self-right': props.alignment === _utils.HorizontalAlignments.RIGHT,
    'align-self-justify': props.alignment === _utils.HorizontalAlignments.JUSTIFY,
    'align-self-spaced': props.alignment === _utils.HorizontalAlignments.SPACED,
    'main-section': props.isMain,
    'middle': props.isMiddle,
    'bottom': props.isBottom
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('div', _extends({}, props, { className: className }));
};