'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuText = exports.MenuItem = exports.Menu = exports.MenuAlignments = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Menu alignment enumerable.
 *
 * @type {{RIGHT: string, CENTER: string}}
 */
var MenuAlignments = exports.MenuAlignments = {
  RIGHT: 'right',
  CENTER: 'center'
};

/**
 * Menu component.
 * http://foundation.zurb.com/sites/docs/menu.html
 *
 * @param {Object} props
 * @returns {Object}
 */
var Menu = exports.Menu = function Menu(props) {
  _checkTypes2.default.assert.maybe.string(props.alignment, 'Property "alignment" must be a string.');
  _checkTypes2.default.assert.maybe.boolean(props.iconsOnTop, 'Property "iconsOnTop" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isExpanded, 'Property "isExpanded" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isVertical, 'Property "isVertical" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isSimple, 'Property "isSimple" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isNested, 'Property "isNested" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'menu', {
    'align-right': props.alignment === MenuAlignments.RIGHT,
    'align-center': props.alignment === MenuAlignments.CENTER,
    'icon-top': props.iconsOnTop,
    'expanded': props.isExpanded,
    'vertical': props.isVertical,
    'simple': props.isSimple,
    'nested': props.isNested
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('ul', _extends({}, props, { className: className }));
};

/**
 * Menu item component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var MenuItem = exports.MenuItem = function MenuItem(props) {
  _checkTypes2.default.assert.maybe.boolean(props.isActive, 'Property "isActive" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className, {
    'active': props.isActive
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('li', _extends({}, props, { className: className }));
};

/**
 * Menu text wrapper-component.
 *
 * @param {Object} props
 * @returns {XML}
 */
var MenuText = exports.MenuText = function MenuText(props) {
  return _react2.default.createElement(MenuItem, _extends({}, props, { className: props.className || 'menu-text' }));
};

exports.default = Menu;