'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PaginationEllipsis = exports.PaginationNext = exports.PaginationPrevious = exports.PaginationItem = exports.Pagination = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _checkTypes = require('check-types');

var _checkTypes2 = _interopRequireDefault(_checkTypes);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Pagination component.
 * http://foundation.zurb.com/sites/docs/pagination.html
 *
 * @param {Object} props
 * @returns {Object}
 */
var Pagination = exports.Pagination = function Pagination(props) {
  _checkTypes2.default.assert.maybe.boolean(props.isCentered, 'Property "isCentered" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className || 'pagination', {
    'text-center': props.isCentered
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('ul', _extends({}, props, { className: className, role: 'navigation' }));
};

/**
 * Pagination item component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var PaginationItem = exports.PaginationItem = function PaginationItem(props) {
  _checkTypes2.default.assert.maybe.boolean(props.isCurrent, 'Property "isCurrent" must be a boolean.');
  _checkTypes2.default.assert.maybe.boolean(props.isDisabled, 'Property "isDisabled" must be a boolean.');

  var className = (0, _utils.createClassName)(props.className, {
    'current': props.isCurrent,
    'disabled': props.isDisabled
  }, (0, _utils.generalClassNames)(props));

  return _react2.default.createElement('li', _extends({}, props, { className: className }));
};

/**
 * Pagination previous wrapper-component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var PaginationPrevious = exports.PaginationPrevious = function PaginationPrevious(props) {
  return _react2.default.createElement(PaginationItem, _extends({}, props, { className: props.className || 'pagination-previous' }));
};

/**
 * Pagination next wrapper-component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var PaginationNext = exports.PaginationNext = function PaginationNext(props) {
  return _react2.default.createElement(PaginationItem, _extends({}, props, { className: props.className || 'pagination-next' }));
};

/**
 * Pagination ellipsis wrapper-component.
 *
 * @param {Object} props
 * @returns {Object}
 */
var PaginationEllipsis = exports.PaginationEllipsis = function PaginationEllipsis(props) {
  return _react2.default.createElement(PaginationItem, _extends({}, props, { className: props.className || 'ellipsis' }));
};

exports.default = Pagination;